pub type HttpCacheDirectiveHeaderValueCollection = *mut ::core::ffi::c_void;
pub type HttpChallengeHeaderValue = *mut ::core::ffi::c_void;
pub type HttpChallengeHeaderValueCollection = *mut ::core::ffi::c_void;
pub type HttpConnectionOptionHeaderValue = *mut ::core::ffi::c_void;
pub type HttpConnectionOptionHeaderValueCollection = *mut ::core::ffi::c_void;
pub type HttpContentCodingHeaderValue = *mut ::core::ffi::c_void;
pub type HttpContentCodingHeaderValueCollection = *mut ::core::ffi::c_void;
pub type HttpContentCodingWithQualityHeaderValue = *mut ::core::ffi::c_void;
pub type HttpContentCodingWithQualityHeaderValueCollection = *mut ::core::ffi::c_void;
pub type HttpContentDispositionHeaderValue = *mut ::core::ffi::c_void;
pub type HttpContentHeaderCollection = *mut ::core::ffi::c_void;
pub type HttpContentRangeHeaderValue = *mut ::core::ffi::c_void;
pub type HttpCookiePairHeaderValue = *mut ::core::ffi::c_void;
pub type HttpCookiePairHeaderValueCollection = *mut ::core::ffi::c_void;
pub type HttpCredentialsHeaderValue = *mut ::core::ffi::c_void;
pub type HttpDateOrDeltaHeaderValue = *mut ::core::ffi::c_void;
pub type HttpExpectationHeaderValue = *mut ::core::ffi::c_void;
pub type HttpExpectationHeaderValueCollection = *mut ::core::ffi::c_void;
pub type HttpLanguageHeaderValueCollection = *mut ::core::ffi::c_void;
pub type HttpLanguageRangeWithQualityHeaderValue = *mut ::core::ffi::c_void;
pub type HttpLanguageRangeWithQualityHeaderValueCollection = *mut ::core::ffi::c_void;
pub type HttpMediaTypeHeaderValue = *mut ::core::ffi::c_void;
pub type HttpMediaTypeWithQualityHeaderValue = *mut ::core::ffi::c_void;
pub type HttpMediaTypeWithQualityHeaderValueCollection = *mut ::core::ffi::c_void;
pub type HttpMethodHeaderValueCollection = *mut ::core::ffi::c_void;
pub type HttpNameValueHeaderValue = *mut ::core::ffi::c_void;
pub type HttpProductHeaderValue = *mut ::core::ffi::c_void;
pub type HttpProductInfoHeaderValue = *mut ::core::ffi::c_void;
pub type HttpProductInfoHeaderValueCollection = *mut ::core::ffi::c_void;
pub type HttpRequestHeaderCollection = *mut ::core::ffi::c_void;
pub type HttpResponseHeaderCollection = *mut ::core::ffi::c_void;
pub type HttpTransferCodingHeaderValue = *mut ::core::ffi::c_void;
pub type HttpTransferCodingHeaderValueCollection = *mut ::core::ffi::c_void;
