pub const CLSID_AudioFrameNativeFactory: ::windows_sys::core::GUID = ::windows_sys::core::GUID { data1: 379626425, data2: 40805, data3: 16642, data4: [147, 103, 44, 218, 58, 79, 55, 42] };
pub const CLSID_VideoFrameNativeFactory: ::windows_sys::core::GUID = ::windows_sys::core::GUID { data1: 3516151914, data2: 1251, data3: 18452, data4: [129, 0, 178, 176, 174, 109, 120, 199] };
pub type IAudioFrameNative = *mut ::core::ffi::c_void;
pub type IAudioFrameNativeFactory = *mut ::core::ffi::c_void;
pub type IVideoFrameNative = *mut ::core::ffi::c_void;
pub type IVideoFrameNativeFactory = *mut ::core::ffi::c_void;
