pub type AppointmentCalendarCancelMeetingRequest = *mut ::core::ffi::c_void;
pub type AppointmentCalendarCancelMeetingRequestEventArgs = *mut ::core::ffi::c_void;
pub type AppointmentCalendarCreateOrUpdateAppointmentRequest = *mut ::core::ffi::c_void;
pub type AppointmentCalendarCreateOrUpdateAppointmentRequestEventArgs = *mut ::core::ffi::c_void;
pub type AppointmentCalendarForwardMeetingRequest = *mut ::core::ffi::c_void;
pub type AppointmentCalendarForwardMeetingRequestEventArgs = *mut ::core::ffi::c_void;
pub type AppointmentCalendarProposeNewTimeForMeetingRequest = *mut ::core::ffi::c_void;
pub type AppointmentCalendarProposeNewTimeForMeetingRequestEventArgs = *mut ::core::ffi::c_void;
pub type AppointmentCalendarSyncManagerSyncRequest = *mut ::core::ffi::c_void;
pub type AppointmentCalendarSyncManagerSyncRequestEventArgs = *mut ::core::ffi::c_void;
pub type AppointmentCalendarUpdateMeetingResponseRequest = *mut ::core::ffi::c_void;
pub type AppointmentCalendarUpdateMeetingResponseRequestEventArgs = *mut ::core::ffi::c_void;
pub type AppointmentDataProviderConnection = *mut ::core::ffi::c_void;
pub type AppointmentDataProviderTriggerDetails = *mut ::core::ffi::c_void;
